﻿# -*- coding: utf-8 -*-
"""
製品情報の整合性チェックを行います
"""
# 使用プラグイン言語キ―：
#   PlgErr_ProdInfo_TitleEmpty
#     タイトルが空欄です。
#   PlgErr_ProdInfo_InvalidProdCode
#     不正な製品コードです。
#   PlgErr_ProdInfo_InvalidAocCode
#     追加コンテンツは、イニシャルコードの欄にバリエーションも入力してください。("****-XX" の型式)


import cse
import re

def DoCheckProdInfo(prodinfo, errors):
  # エラーの種類
  errtype = "ERR_ProdInfoEmpty"
  errmsgttl = "PlgErr_ProdInfo_TitleEmpty"
  errmsgprd = "PlgErr_ProdInfo_InvalidProdCode"
  errmsgaoc = "PlgErr_ProdInfo_InvalidAocCode"
  
  # タイトルが必要
  if prodinfo.Title == None or prodinfo.Title == "":
    errors.append({'type': errtype, 'msg': errmsgttl, 'dlg': 'productsetting'})
  
  
  # 製品分類コードは3文字
  if re.match(r"^[A-Z0-9]{3}$", prodinfo.ClassCode) == None:
    errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
    return
  
  # 形態コードは1文字
  if re.match(r"^[A-Z0-9]$", prodinfo.FormCode) == None:
    errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
    return
  
  # イニシャルコードの整合性
  if (prodinfo.ClassCode == "CTR" or prodinfo.ClassCode == "WUP") and prodinfo.FormCode == "M":
    if re.match(r"^\w{4}-[a-fA-F0-9]{2}$", prodinfo.InitCode) == None:
      # 形態コードが'M'の場合は、イニシャルコード+バリエーションが必要
      errors.append({'type': errtype, 'msg': errmsgaoc, 'dlg': 'productsetting'})
      return
  else:
    if re.match(r"^\w{4}$", prodinfo.InitCode) == None:
      # 形態コードが'M'以外の場合は、イニシャルコードのみ
      errors.append({'type': errtype, 'msg': errmsgprd, 'dlg': 'productsetting'})
      return
  


# 出力シートチェックメソッド
def CheckOutSheet(s, e):
  # プラグイン実行イベントデータ
  v = e.Value
  
  # チェックの実行
  DoCheckProdInfo(v.prodinfo, v.errors)
  


cse.addhandler("RequestCheckOutSheet", CheckOutSheet)

